@@ -62,6 +62,7 @@ WARNING_MESSAGES = {
     "TXT005": "contains a LIST style with list markers. This style will be ignored",
     "TXT006": "uses OpenType features not supported by Sketch: {features}. They will be ignored",
     "SHP001": "contains a line with at least one 'Reversed triangle' end. This type of marker does not exist in Sketch. It has been converted to a 'Line' type marker",
+    "SHP002": "does not have any points. It will be skipped",
     "STY001": "contains a layer blur and a background blur. Only one will be converted",
     "STY002": "contains a DIAMOND gradient, which is not supported. It is converted to a RADIAL gradient",
     "STY003": "contains a fill with a non-standard blend mode, which is not supported at the fill level (us the layer blend mode instead). It will be ignored",
@@ -91,6 +92,9 @@ WARNING_MESSAGES = {
     "GRD006": "has a row layout with an offset that is not supported. The offset will be ignored",
     "GRD007": "has a row layout with non-integer ratio between gutter and row size. The row layout will not be converted",
     "GRD008": "has a row and column layout. The rows will only be as wide as the columns (instead of taking the entire width of the artboard)",
+    "IMG001": "appears to be corrupted in the .fig file, it will not be converted. Try passing --force-convert-images to try to convert it anyway",
+    "IMG002": "appears to be corrupted in the .fig file, it will not be converted",
+    "IMG003": "is missing from the .fig file, it will not be converted",
 }
 
 
